package Task::BeLike::SHARYANTO::Spec;

our $VERSION = '0.01'; # VERSION


1;
# ABSTRACT: SHARYANTO's spec distributions

__END__
=pod

=head1 NAME

Task::BeLike::SHARYANTO::Spec - SHARYANTO's spec distributions

=head1 VERSION

version 0.01

=head1 DESCRIPTION

This task will install all SHARYANTO's spec distributions, i.e. those that
contain only specification and not implementation.

=head1 TASK CONTENTS

=head2 Included modules

=head3 L<Riap>

=head3 L<Rinci>

=head3 L<Sah>

=head3 L<Setup>

=head3 L<Unixish>

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

